name = "rips"

import os
import sys
sys.path.insert(0, os.path.join(os.path.dirname(__file__), 'generated'))

from resinsight_classes import *

from .case import Case, EclipseCase, GeoMechCase
from .grid import Grid
from .instance import Instance
from .pdmobject import PdmObjectBase
from .view import View
from .project import Project
from .plot import Plot, PlotWindow
from .contour_map import EclipseContourMap, GeoMechContourMap
from .well_log_plot import WellLogPlot
from .simulation_well import SimulationWell



###########################################################################################
# This example will asynchronously calculate the average value for SOIL for all time steps
###########################################################################################

import rips
import itertools
import time

resinsight     = rips.Instance.find()

start          = time.time()

# Get the case with case id 0
case           = resinsight.project.case(case_id=0)

# Get a list of all time steps
timeSteps      = case.time_steps()

averages = []
for i in range(0, len(timeSteps)):
    # Get the results from time step i asynchronously
    # It actually returns a generator object almost immediately
	result_chunks = case.active_cell_property_async('DYNAMIC_NATIVE', 'SOIL', i)
	mysum = 0.0
	count = 0
    # Loop through and append the average. each time we loop resultChunks
    # We will trigger a read of the input data, meaning the script will start
    # Calculating averages before the whole resultValue for this time step has been received
	for chunk in result_chunks:
		mysum += sum(chunk.values)
		count += len(chunk.values)

	averages.append(mysum/count)

end = time.time()
print("Time elapsed: ", end - start)
print(averages)


import sys
import os
import pytest
import grpc
import tempfile

sys.path.insert(1, os.path.join(sys.path[0], '../../'))
import rips

import dataroot


def test_loadProject(rips_instance, initialize_test):
    project = rips_instance.project.open(dataroot.PATH + "/TEST10K_FLT_LGR_NNC/10KWithWellLog.rsp")
    case = project.cases()[0]
    assert(case is not None)
    assert(case.name == "TEST10K_FLT_LGR_NNC")
    assert(case.id == 0)
    cases = rips_instance.project.cases()
    assert(len(cases) is 1)


def test_well_log_plots(rips_instance, initialize_test):
    project = rips_instance.project.open(dataroot.PATH + "/TEST10K_FLT_LGR_NNC/10KWithWellLog.rsp")
    plots = project.plots()
    well_log_plots = []
    for plot in plots:
        if isinstance(plot, rips.WellLogPlot):
            assert(plot.depth_type == "MEASURED_DEPTH")
            well_log_plots.append(plot)
    assert(len(well_log_plots) == 2)

    with tempfile.TemporaryDirectory(prefix="rips") as tmpdirname:
        for well_log_plot in well_log_plots:
            well_log_plot.depth_type = "TRUE_VERTICAL_DEPTH_RKB"
            well_log_plot.update()
            if rips_instance.is_gui():
                well_log_plot.export_snapshot(tmpdirname)
            well_log_plot.export_data_as_las(tmpdirname)
        files = os.listdir(tmpdirname)
        print(files)
        if rips_instance.is_gui():
            assert(len(files) == 4)
        else:
            assert(len(files) == 2)

    plots2 = project.plots()
    for plot2 in plots2:
        if isinstance(plot2, rips.WellLogPlot):
            assert(plot2.depth_type == "TRUE_VERTICAL_DEPTH_RKB")


@pytest.mark.skipif(sys.platform.startswith('linux'), reason="Brugge is currently exceptionally slow on Linux")
def test_loadGridCaseGroup(rips_instance, initialize_test):
    case_paths = []
    case_paths.append(dataroot.PATH + "/Case_with_10_timesteps/Real0/BRUGGE_0000.EGRID")
    case_paths.append(dataroot.PATH + "/Case_with_10_timesteps/Real10/BRUGGE_0010.EGRID")
    grid_case_group = rips_instance.project.create_grid_case_group(case_paths=case_paths)
    assert(grid_case_group is not None and grid_case_group.group_id == 0)


def test_exportSnapshots(rips_instance, initialize_test):
    if not rips_instance.is_gui():
        pytest.skip("Cannot run test without a GUI")

    case_path = dataroot.PATH + "/TEST10K_FLT_LGR_NNC/TEST10K_FLT_LGR_NNC.EGRID"
    rips_instance.project.load_case(case_path)
    with tempfile.TemporaryDirectory(prefix="rips") as tmpdirname:
        print("Temporary folder: ", tmpdirname)
        rips_instance.set_export_folder(export_type='SNAPSHOTS', path=tmpdirname)
        rips_instance.project.export_snapshots()
        print(os.listdir(tmpdirname))
#        assert(len(os.listdir(tmpdirname)) > 0)
        for fileName in os.listdir(tmpdirname):
            assert(os.path.splitext(fileName)[1] == '.png')



# Load ResInsight Processing Server Client Library
import rips
# Launch ResInsight with last project file and a Window size of 600x1000 pixels
resinsight = rips.Instance.launch(command_line_parameters=['--last', '--size', 600, 1000])
# Get a list of all cases
cases = resinsight.project.cases()

print ("Got " + str(len(cases)) + " cases: ")
for case in cases:
    print("Case name: " + case.name)
    print("Case grid path: " + case.file_path)



# Load ResInsight Processing Server Client Library
import rips
# Connect to ResInsight instance
resinsight = rips.Instance.find()
# Example code
print("ResInsight version: " + resinsight.version_string())

modeled_well_paths = resinsight.project.descendants(rips.ModeledWellPath)

for wellpath in modeled_well_paths:
    geometry = wellpath.well_path_geometry()
    geometry.print_object_info()
    reference_point = geometry.reference_point
    reference_point[0] += 100
    geometry.update()
    geometry.print_object_info()


############################################################################
# This example prints center and corners for the currently selected cells
# in ResInsight
############################################################################

import rips

resinsight  = rips.Instance.find()
if resinsight is not None:
    cases = resinsight.project.cases()

    print ("Got " + str(len(cases)) + " cases: ")
    for case in cases:
        print(case.name)
        cells = case.selected_cells()
        print("Found " + str(len(cells)) + " selected cells")

        time_step_info = case.time_steps()

        for (idx, cell) in enumerate(cells):
            print("Selected cell: [{}, {}, {}] grid: {}".format(cell.ijk.i+1, cell.ijk.j+1, cell.ijk.k+1, cell.grid_index))

            # Get the grid and dimensions
            grid = case.grids()[cell.grid_index]
            dimensions = grid.dimensions()

            # Map ijk to cell index
            cell_index = dimensions.i * dimensions.j * cell.ijk.k + dimensions.i * cell.ijk.j + cell.ijk.i

            # Print the cell center
            cell_centers = grid.cell_centers()
            cell_center = cell_centers[cell_index]
            print("Cell center: [{}, {}, {}]".format(cell_center.x, cell_center.y, cell_center.z))

            # Print the cell corners
            cell_corners = grid.cell_corners()[cell_index]
            print("Cell corners:")
            print("c0:\n" + str(cell_corners.c0))
            print("c1:\n" + str(cell_corners.c1))
            print("c2:\n" + str(cell_corners.c2))
            print("c3:\n" + str(cell_corners.c3))
            print("c4:\n" + str(cell_corners.c4))
            print("c5:\n" + str(cell_corners.c5))
            print("c6:\n" + str(cell_corners.c6))
            print("c7:\n" + str(cell_corners.c7))

            for (tidx, timestep) in enumerate(time_step_info):
                # Read the full SOIL result for time step
                soil_results = case.selected_cell_property('DYNAMIC_NATIVE', 'SOIL', tidx)
                print("SOIL: {} ({}.{}.{})".format(soil_results[idx], timestep.year, timestep.month, timestep.day))



import sys
import os
import grpc
import pytest

import rips.generated.NNCProperties_pb2 as NNCProperties_pb2

sys.path.insert(1, os.path.join(sys.path[0], '../../'))
import rips

import dataroot


def test_10kSync(rips_instance, initialize_test):
    casePath = dataroot.PATH + "/TEST10K_FLT_LGR_NNC/TEST10K_FLT_LGR_NNC.EGRID"
    case = rips_instance.project.load_case(path=casePath)

    properties = case.available_nnc_properties()
    assert(len(properties) == 1)

    assert("TRAN" == properties[0].name)
    assert(NNCProperties_pb2.NNCPropertyType.Value('NNC_STATIC') == properties[0].property_type)

    nnc_connections = case.nnc_connections()
    assert(len(nnc_connections) == 3627)

    connection = nnc_connections[0]
    assert(connection.cell1.i == 33)
    assert(connection.cell1.j == 40)
    assert(connection.cell1.k == 14)
    assert(connection.cell_grid_index1 == 0)

    tran_vals = case.nnc_connections_static_values("TRAN")
    assert(len(tran_vals) == len(nnc_connections))

    for t in tran_vals:
        assert(isinstance(t, float))

    # Generate some data
    new_data = []
    for (c, _) in enumerate(nnc_connections):
        new_data.append(float(c))

    property_name = "NEW_PROP"
    case.set_nnc_connections_values(new_data, property_name, 0)
    new_prop_vals = case.nnc_connections_generated_values(property_name, 0)
    assert(len(new_prop_vals) == len(new_data))
    for i in range(0, len(new_data)):
        assert(new_data[i] == new_prop_vals[i])

    # Set some other data for second time step
    for i in range(0, len(new_data)):
        new_data[i] = new_data[i] * 2.0

    case.set_nnc_connections_values(new_data, property_name, 1)
    new_prop_vals = case.nnc_connections_generated_values(property_name, 1)
    assert(len(new_prop_vals) == len(nnc_connections))
    for i in range(0, len(new_data)):
        assert(new_data[i] == new_prop_vals[i])


def test_non_existing_dynamic_values(rips_instance, initialize_test):
    casePath = dataroot.PATH + "/TEST10K_FLT_LGR_NNC/TEST10K_FLT_LGR_NNC.EGRID"
    case = rips_instance.project.load_case(path=casePath)

    with pytest.raises(grpc.RpcError):
        case.nnc_connections_dynamic_values("x", 0)


def test_invalid_time_steps(rips_instance, initialize_test):
    casePath = dataroot.PATH + "/TEST10K_FLT_LGR_NNC/TEST10K_FLT_LGR_NNC.EGRID"
    case = rips_instance.project.load_case(path=casePath)
    with pytest.raises(grpc.RpcError):
        case.nnc_connections_generated_values("Formation Allan", 9999)



# Load ResInsight Processing Server Client Library
import rips
import tempfile
from os.path import expanduser
from pathlib import Path

# Connect to ResInsight instance
resinsight = rips.Instance.find()
# Example code
project = resinsight.project

# Create fracture model template
home_dir = expanduser("~")
elastic_properties_file_path = (Path(home_dir) / "elastic_properties.csv").as_posix()
print("Elastic properties file path:", elastic_properties_file_path)

facies_properties_file_path = (Path(home_dir) / "facies_id.roff").as_posix()
print("Facies properties file path:", facies_properties_file_path)

fmt_collection = project.descendants(rips.FractureModelTemplateCollection)[0]
fracture_model_template = fmt_collection.new_fracture_model_template(elastic_properties_file_path=elastic_properties_file_path,
                                                                     facies_properties_file_path=facies_properties_file_path)
fracture_model_template.overburden_formation = "Garn"
fracture_model_template.overburden_facies = "Shale"
fracture_model_template.underburden_formation = "Garn"
fracture_model_template.underburden_facies = "Shale"
fracture_model_template.overburden_height = 68
fracture_model_template.update()
print("Overburden: ", fracture_model_template.overburden_formation)


# Set eclipse result for facies definition
eclipse_result = fracture_model_template.facies_properties().facies_definition()
eclipse_result.result_type = "INPUT_PROPERTY"
eclipse_result.result_variable = "OPERNUM_1"
eclipse_result.update()

# Set eclipse result for non-net layers
non_net_layers = fracture_model_template.non_net_layers()
non_net_layers_result = non_net_layers.facies_definition()
non_net_layers_result.result_type = "STATIC_NATIVE"
non_net_layers_result.result_variable = "NTG"
non_net_layers_result.update()
non_net_layers.formation = "Not"
non_net_layers.facies = "Shale"
non_net_layers.update()


# Add some scaling factors
elastic_properties = fracture_model_template.elastic_properties()
elastic_properties.add_property_scaling(formation="Garn", facies="Calcite", property="YOUNGS_MODULUS", scale=1.44)


# Find a well
well_path = project.well_path_by_name("B-2 H")
print("well path:", well_path)
fracture_model_collection = project.descendants(rips.FractureModelCollection)[0]

# Find a case
cases = resinsight.project.cases()
case = cases[0]

# Use the last time step
time_steps = case.time_steps()
time_step = time_steps[len(time_steps) - 1]

# Create fracture model at a give measured depth
measured_depth = 3200.0
fracture_model = fracture_model_collection.new_fracture_model(eclipse_case=case,
                                                              time_step=time_step,
                                                              well_path=well_path,
                                                              measured_depth=measured_depth,
                                                              fracture_model_template=fracture_model_template)

export_folder = tempfile.gettempdir()

print("Exporting fracture model to: ", export_folder)
fracture_model.export_to_file(directory_path=export_folder)

# Create a fracture mode plot
fracture_model_plot_collection = project.descendants(rips.FractureModelPlotCollection)[0]
fracture_model_plot = fracture_model_plot_collection.new_fracture_model_plot(fracture_model=fracture_model)

print("Exporting fracture model plot to: ", export_folder)
fracture_model_plot.export_snapshot(export_folder=export_folder)

print("Setting measured depth and perforation length.")
fracture_model.measured_depth = 3300.0
fracture_model.perforation_length = 123.445
fracture_model.update()



import sys
import os

sys.path.insert(1, os.path.join(sys.path[0], '../../'))
import rips

import dataroot


def test_10k(rips_instance, initialize_test):
    case_path = dataroot.PATH + "/TEST10K_FLT_LGR_NNC/TEST10K_FLT_LGR_NNC.EGRID"
    case = rips_instance.project.load_case(path=case_path)
    assert(len(case.grids()) == 2)
    cell_count_info = case.cell_count()

    sim_wells = case.simulation_wells()
    assert(len(sim_wells) == 3)

    assert(sim_wells[0].name == "GI1")
    assert(sim_wells[1].name == "GP1")
    assert(sim_wells[2].name == "GP2")

    timesteps = case.time_steps()

    # On time step 0 all simulation wells are undefined
    for sim_well in sim_wells:
        status = sim_well.status(0)
        assert(status.well_type == "NotDefined")

    # On time step 3 all wells are producing
    for sim_well in sim_wells:
        status = sim_well.status(3)
        assert(status.well_type == "Producer")

    # On time step 0 all simulation wells have no cells
    for sim_well in sim_wells:
        cells = sim_well.cells(0)
        assert(len(cells) == 0)

    # On the other time steps there should be cells
    expected_cell_count = {}
    expected_cell_count["GP1"] = 105
    expected_cell_count["GI1"] = 38
    expected_cell_count["GP2"] = 18
    for sim_well in sim_wells:
        for (tidx, timestep) in enumerate(timesteps):
            if (tidx > 0):
                cells = sim_well.cells(tidx)
                print("well: " + sim_well.name + " timestep: " +
                      str(tidx) + " cells:" + str(len(cells)))
                assert(len(cells) == expected_cell_count[sim_well.name])



import sys
import os
import math

sys.path.insert(1, os.path.join(sys.path[0], '../../'))
import rips

import dataroot


def test_summary_import_and_find(rips_instance, initialize_test):
    casePath = dataroot.PATH + "/flow_diagnostics_test/SIMPLE_SUMMARY2.SMSPEC"
    summary_case = rips_instance.project.import_summary_case(casePath)
    assert(summary_case.id == 1)

    case_id = 234
    found_summary_case = rips_instance.project.summary_case(case_id)
    assert(found_summary_case is None)

    correct_case_id = 1
    found_summary_case = rips_instance.project.summary_case(correct_case_id)
    assert(found_summary_case is not None)

    rips_instance.project.close()
    correct_case_id = 1
    found_summary_case = rips_instance.project.summary_case(correct_case_id)
    assert(found_summary_case is None)


def test_summary_data(rips_instance, initialize_test):
    casePath = dataroot.PATH + "/flow_diagnostics_test/SIMPLE_SUMMARY2.SMSPEC"
    summary_case = rips_instance.project.import_summary_case(casePath)
    assert(summary_case.id == 1)

    addresses = summary_case.available_addresses()
    assert(len(addresses.values) == 343)

    summary_data = summary_case.summary_vector_values("FOPT")
    assert(len(summary_data.values) == 60)


def test_summary_resample(rips_instance, initialize_test):
    casePath = dataroot.PATH + "/flow_diagnostics_test/SIMPLE_SUMMARY2.SMSPEC"
    summary_case = rips_instance.project.import_summary_case(casePath)
    assert(summary_case.id == 1)

    summary_data_sampled = summary_case.resample_values("FOPT", "NONE")
    assert(len(summary_data_sampled.values) == 60)
    assert(len(summary_data_sampled.time_steps) == 60)

    summary_data_sampled = summary_case.resample_values("FOPT", "DAY")
    assert(len(summary_data_sampled.values) == 721)
    assert(len(summary_data_sampled.time_steps) == 721)

    summary_data_sampled = summary_case.resample_values("FOPT", "MONTH")
    assert(len(summary_data_sampled.values) == 24)
    assert(len(summary_data_sampled.time_steps) == 24)

    summary_data_sampled = summary_case.resample_values("FOPT", "QUARTER")
    assert(len(summary_data_sampled.values) == 8)
    assert(len(summary_data_sampled.time_steps) == 8)

    summary_data_sampled = summary_case.resample_values("FOPT", "YEAR")
    assert(len(summary_data_sampled.values) == 3)
    assert(len(summary_data_sampled.time_steps) == 3)



"""
ResInsight 2d plot module
"""
import Commands_pb2

from .pdmobject import PdmObjectBase, add_method
from resinsight_classes import PlotWindow, Plot


@add_method(PlotWindow)
def export_snapshot(self, export_folder='', file_prefix='', output_format='PNG'):
    """ Export snapshot for the current plot

    Arguments:
        export_folder(str): The path to export to. By default will use the global export folder
        prefix (str): Exported file name prefix
        output_format(str): Enum string. Can be 'PNG' or 'PDF'.

    """
    return self._execute_command(
        exportSnapshots=Commands_pb2.ExportSnapshotsRequest(type='PLOTS',
                                                            prefix=file_prefix,
                                                            viewId=self.id,
                                                            exportFolder=export_folder,
                                                            plotOutputFormat=output_format))



######################################################################
# This script applies a flow diagnostics cell result to the first view in the project
######################################################################

# Load ResInsight Processing Server Client Library
import rips
# Connect to ResInsight instance
resinsight = rips.Instance.find()

view = resinsight.project.view(view_id=1)
#view.apply_flow_diagnostics_cell_result(result_variable='Fraction',
#                                    selection_mode='FLOW_TR_INJ_AND_PROD')
                                    
# Example of setting individual wells. Commented out because well names are case specific.
view.apply_flow_diagnostics_cell_result(result_variable='Fraction',
                                    selection_mode='FLOW_TR_BY_SELECTION',
                                    injectors = ['C-1H', 'C-2H', 'F-2H'],
                                    producers = ['B-1AH', 'B-3H', 'D-1H'])



"""
ResInsight Well Log Plot plot module
"""

import Commands_pb2

from .plot import Plot
from .pdmobject import PdmObjectBase, add_method
from resinsight_classes import WellLogPlot


@add_method(WellLogPlot)
def export_data_as_las(self, export_folder, file_prefix='', export_tvdrkb=False, capitalize_file_names=False, resample_interval=0.0, convert_to_standard_units=False):
    """ Export LAS file(s) for the current plot

    Arguments:
        export_folder(str): The path to export to. By default will use the global export folder
        file_prefix (str): Exported file name prefix
        export_tvdrkb(bool): Export in TVD-RKB format
        capitalize_file_names(bool): Make all file names upper case
        resample_interval(double): if > 0.0 the files will be resampled

    Returns:
        A list of files exported
    """
    res = self._execute_command(exportWellLogPlotData=Commands_pb2.ExportWellLogPlotDataRequest(exportFormat='LAS',
                                                                                                viewId=self.id,
                                                                                                exportFolder=export_folder,
                                                                                                filePrefix=file_prefix,
                                                                                                exportTvdRkb=export_tvdrkb,
                                                                                                capitalizeFileNames=capitalize_file_names,
                                                                                                resampleInterval=resample_interval,
                                                                                                convertCurveUnits=convert_to_standard_units))
    return res.exportWellLogPlotDataResult.exportedFiles


@add_method(WellLogPlot)
def export_data_as_ascii(self, export_folder, file_prefix='', capitalize_file_names=False):
    """ Export LAS file(s) for the current plot

    Arguments:
        export_folder(str): The path to export to. By default will use the global export folder
        file_prefix (str): Exported file name prefix
        capitalize_file_names(bool): Make all file names upper case

    Returns:
        A list of files exported
    """
    res = self._execute_command(exportWellLogPlotData=Commands_pb2.ExportWellLogPlotDataRequest(exportFormat='ASCII',
                                                                                                viewId=self.id,
                                                                                                exportFolder=export_folder,
                                                                                                filePrefix=file_prefix,
                                                                                                exportTvdRkb=False,
                                                                                                capitalizeFileNames=capitalize_file_names,
                                                                                                resampleInterval=0.0))
    return res.exportWellLogPlotDataResult.exportedFiles



import sys
import os
import grpc
import pytest
import tempfile

sys.path.insert(1, os.path.join(sys.path[0], '../../'))
import rips

import dataroot


def test_10kAsync(rips_instance, initialize_test):
    casePath = dataroot.PATH + "/TEST10K_FLT_LGR_NNC/TEST10K_FLT_LGR_NNC.EGRID"
    case = rips_instance.project.load_case(path=casePath)

    resultChunks = case.active_cell_property_async('DYNAMIC_NATIVE', 'SOIL', 1)
    mysum = 0.0
    count = 0
    for chunk in resultChunks:
        mysum += sum(chunk.values)
        count += len(chunk.values)
    average = mysum / count
    assert(mysum == pytest.approx(621.768, abs=0.001))
    assert(average != pytest.approx(0.0158893, abs=0.0000001))
    assert(average == pytest.approx(0.0558893, abs=0.0000001))


def test_10kSync(rips_instance, initialize_test):
    casePath = dataroot.PATH + "/TEST10K_FLT_LGR_NNC/TEST10K_FLT_LGR_NNC.EGRID"
    case = rips_instance.project.load_case(path=casePath)

    results = case.active_cell_property('DYNAMIC_NATIVE', 'SOIL', 1)
    mysum = sum(results)
    average = mysum / len(results)
    assert(mysum == pytest.approx(621.768, abs=0.001))
    assert(average != pytest.approx(0.0158893, abs=0.0000001))
    assert(average == pytest.approx(0.0558893, abs=0.0000001))


def test_10k_set(rips_instance, initialize_test):
    casePath = dataroot.PATH + "/TEST10K_FLT_LGR_NNC/TEST10K_FLT_LGR_NNC.EGRID"
    case = rips_instance.project.load_case(path=casePath)

    results = case.active_cell_property('DYNAMIC_NATIVE', 'SOIL', 1)
    case.set_active_cell_property(results, 'GENERATED', 'SOIL', 1)


def test_10k_set_out_of_bounds(rips_instance, initialize_test):
    casePath = dataroot.PATH + "/TEST10K_FLT_LGR_NNC/TEST10K_FLT_LGR_NNC.EGRID"
    case = rips_instance.project.load_case(path=casePath)

    results = case.active_cell_property('DYNAMIC_NATIVE', 'SOIL', 1)
    results.append(5.0)
    with pytest.raises(grpc.RpcError):
        assert case.set_active_cell_property(results, 'GENERATED', 'SOIL', 1)


def test_10k_set_out_of_bounds_client(rips_instance, initialize_test):
    casePath = dataroot.PATH + "/TEST10K_FLT_LGR_NNC/TEST10K_FLT_LGR_NNC.EGRID"
    case = rips_instance.project.load_case(path=casePath)

    results = case.active_cell_property('DYNAMIC_NATIVE', 'SOIL', 1)
    case.chunk_size = len(results)
    results.append(5.0)
    with pytest.raises(IndexError):
        assert case.set_active_cell_property(results, 'GENERATED', 'SOIL', 1)


def createResult(poroChunks, permxChunks):
    for (poroChunk, permxChunk) in zip(poroChunks, permxChunks):
        resultChunk = []
        for (poro, permx) in zip(poroChunk.values, permxChunk.values):
            resultChunk.append(poro * permx)
        yield resultChunk


def checkResults(poroValues, permxValues, poropermxValues):
    for (poro, permx, poropermx) in zip(poroValues, permxValues, poropermxValues):
        recalc = poro * permx
        assert(recalc == pytest.approx(poropermx, rel=1.0e-10))


def test_10k_PoroPermX(rips_instance, initialize_test):
    casePath = dataroot.PATH + "/TEST10K_FLT_LGR_NNC/TEST10K_FLT_LGR_NNC.EGRID"
    case = rips_instance.project.load_case(path=casePath)

    poroChunks = case.active_cell_property_async('STATIC_NATIVE', 'PORO', 0)
    permxChunks = case.active_cell_property_async('STATIC_NATIVE', 'PERMX', 0)

    case.set_active_cell_property_async(createResult(
        poroChunks, permxChunks), 'GENERATED', 'POROPERMXAS', 0)

    poro = case.active_cell_property('STATIC_NATIVE', 'PORO', 0)
    permx = case.active_cell_property('STATIC_NATIVE', 'PERMX', 0)
    poroPermX = case.active_cell_property('GENERATED', 'POROPERMXAS', 0)

    checkResults(poro, permx, poroPermX)


def test_exportPropertyInView(rips_instance, initialize_test):
    case_path = dataroot.PATH + "/TEST10K_FLT_LGR_NNC/TEST10K_FLT_LGR_NNC.EGRID"
    rips_instance.project.load_case(case_path)
    with tempfile.TemporaryDirectory(prefix="rips") as tmpdirname:
        print("Temporary folder: ", tmpdirname)
        rips_instance.set_export_folder(export_type='PROPERTIES', path=tmpdirname)
        case = rips_instance.project.cases()[0]
        view = case.views()[0]
        view.export_property()
        expected_file_name = case.name + "-" + str("3D_View") + "-" + "T0" + "-SOIL"
        full_path = tmpdirname + "/" + expected_file_name
        assert(os.path.exists(full_path))



###########################################################################################
# This example will synchronously calculate the average value for SOIL for all time steps
###########################################################################################
import rips
import itertools
import time

resinsight     = rips.Instance.find()

start          = time.time()

# Get the case with case id 0
case           = resinsight.project.case(case_id=0)

# Get a list of all time steps
time_steps      = case.time_steps()

averages = []
for i in range(0, len(time_steps)):
    # Get a list of all the results for time step i
	results = case.active_cell_property('DYNAMIC_NATIVE', 'SOIL', i)
	mysum = sum(results)
	averages.append(mysum/len(results))

end = time.time()
print("Time elapsed: ", end - start)
print(averages)


#######################################
# This example connects to ResInsight
#######################################
import rips

resinsight  = rips.Instance.find()

if resinsight is None:
    print('ERROR: could not find ResInsight')
else:
	print('Successfully connected to ResInsight')